CKEDITOR.plugins.setLang('youtube', 'pt-br', {
	button : 'Inserir Vídeo do Youtube',
	title : 'Inserir Vídeo do Youtube',
	txtEmbed : 'Cole aqui o código embed de um vídeo do Youtube',
	txtUrl : 'Cole aqui uma URL de um vídeo do Youtube',
	txtWidth : 'Largura',
	txtHeight : 'Altura',
	chkRelated : 'Mostrar vídeos sugeridos ao final do vídeo',
	txtStartAt : 'Iniciar em (ss ou mm:ss ou hh:mm:ss)',
	chkPrivacy : 'Ativar o modo de privacidade aprimorada',
	chkOlderCode : 'Usar código de incorporação antigo',
	chkAutoplay : 'Reproduzir automaticamente',
	chkControls: 'Mostrar controles do player',
	noCode : 'Você precisa informar um código embed ou uma URL',
	invalidEmbed : 'O código informado não parece ser válido',
	invalidUrl : 'A URL informada não parece ser válida',
	or : 'ou',
	noWidth : 'Você deve informar a largura do vídeo',
	invalidWidth : 'Informe uma largura válida',
	noHeight : 'Você deve informar a altura do vídeo',
	invalidHeight : 'Informe uma altura válida',
	invalidTime : 'O tempo informado é inválido',
	txtResponsive : 'Vídeo responsivo',
	txtNoEmbed : 'Somente imagem e link para o vídeo'
});
